@@ -1,7 +1,7 @@
+from __future__ import annotations
+
 import ast
 from typing import Iterable
-from typing import List
-from typing import Tuple
 
 from tokenize_rt import Offset
 from tokenize_rt import Token
@@ -16,7 +16,7 @@ from pyupgrade._token_helpers import find_closing_bracket
 from pyupgrade._token_helpers import find_open_paren
 
 
-def _fix_default_encoding(i: int, tokens: List[Token]) -> None:
+def _fix_default_encoding(i: int, tokens: list[Token]) -> None:
     i = find_open_paren(tokens, i + 1)
     j = find_closing_bracket(tokens, i)
     del tokens[i + 1:j]
@@ -27,7 +27,7 @@ def visit_Call(
         state: State,
         node: ast.Call,
         parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
             state.settings.min_version >= (3,) and
             isinstance(node.func, ast.Attribute) and
