@@ -1,7 +1,7 @@
+from __future__ import annotations
+
 import ast
 from typing import Iterable
-from typing import List
-from typing import Tuple
 
 from tokenize_rt import Offset
 from tokenize_rt import Token
@@ -15,7 +15,7 @@ from pyupgrade._token_helpers import find_closing_bracket
 from pyupgrade._token_helpers import find_comprehension_opening_bracket
 
 
-def _replace_list_comprehension(i: int, tokens: List[Token]) -> None:
+def _replace_list_comprehension(i: int, tokens: list[Token]) -> None:
     start = find_comprehension_opening_bracket(i, tokens)
     end = find_closing_bracket(tokens, start)
     tokens[start] = tokens[start]._replace(src='(')
@@ -27,7 +27,7 @@ def visit_Assign(
         state: State,
         node: ast.Assign,
         parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
             state.settings.min_version >= (3,) and
             len(node.targets) == 1 and
